==> music21-6.5.0.tar.gz: music21-6.5.0/README.md <==
# music21 #

music21 -- A Toolkit for Computational Musicology

Copyright © 2006-2021, Michael Scott Cuthbert and cuthbertLab

For more information, visit:
http://web.mit.edu/music21 or http://music21.readthedocs.org/en/latest/index.html

And to install, see:
http://web.mit.edu/music21/doc/usersGuide/usersGuide_01_installing.html

Music21 runs on Python 3.6+.  Version 4 was the last version to support Python 2 or Py3.4;
Version 5 was the last version to support Py3.5.

Released under the BSD (3-clause) license. Music21 may also be used
under the LGPL license.  See LICENSE.
Externally provided software (including the MIT licensed Lilypond/MusicXML test Suite) and
music encoding in the corpus may have different licenses. A no-corpus version of music21
is available also on GitHub

[![Build Status](https://travis-ci.org/cuthbertLab/music21.svg?branch=master)](https://travis-ci.org/cuthbertLab/music21)
[![Coverage Status](https://coveralls.io/repos/github/cuthbertLab/music21/badge.svg?branch=master)](https://coveralls.io/github/cuthbertLab/music21?branch=master)

## Mailing list ##

See: https://groups.google.com/forum/#!forum/music21list

## Community Code of Conduct ##

Music21 encourages contributions, discussions, and usage from all people interested in
music and computers. This encouragement extends to all people regardless of (among other aspects)
gender, race, sexual orientation, disability, religion, appearance, veteran status,
gender identity, socioeconomic status, or nationality.

Members of the community will strive to be friendly, patient, and welcoming, especially of
viewpoints and experiences different from our own. We reject harassment and contributions
(in mail, comments, or code) that belittle individuals or groups of people.

We ask all members of the community to be mindful particularly about assumptions of the
gender of users (choice of pronouns in comments and code). We recognize that members
sometimes make mistakes and will, in general, accept sincere regrets for such cases.
Blatant or repeated violations of the code will result in the removal of the
contributor’s participation in the community.

The maintainers of music21 and associated sites will commit themselves to enforcing
this code of conduct. Users who notice violations, including instances of abuse,
harassment, or otherwise unacceptable behavior are requested to contact cuthbert@mit.edu.
Maintainers will respect confidentiality with regards to reports.

==> music21-7.1.0.tar.gz: music21-7.1.0/README.md <==
# music21 #

music21 -- A Toolkit for Computational Musicology

Copyright © 2006-2021, Michael Scott Cuthbert and cuthbertLab

For more information, visit:
https://web.mit.edu/music21

And to install, see:
https://web.mit.edu/music21/doc/usersGuide/usersGuide_01_installing.html

Music21 runs on Python 3.7+.  Use version 4 on Python 2 or Py3.4, version 5
on Py3.5, version 6 on Py3.6.

Released under the BSD (3-clause) license. Music21 may also be used
under the LGPL license.  See LICENSE.
Externally provided software (including the MIT licensed Lilypond/MusicXML test Suite) and
music encoding in the corpus may have different licenses. A no-corpus version of music21
is available also on GitHub.

[![Build Status](https://github.com/cuthbertLab/music21/workflows/maincheck/badge.svg)](https://github.com/cuthbertLab/music21)
[![Lint Status](https://github.com/cuthbertLab/music21/workflows/PyLint/badge.svg)](https://github.com/cuthbertLab/music21)
[![Coverage Status](https://coveralls.io/repos/github/cuthbertLab/music21/badge.svg?branch=master)](https://coveralls.io/github/cuthbertLab/music21?branch=master)

## Mailing list ##

See: https://groups.google.com/forum/#!forum/music21list

## Contributing Guide ##

[Contributing Guide](CONTRIBUTING.md)

## Community Code of Conduct ##

Music21 encourages contributions, discussions, and usage from all people interested in
music and computers. This encouragement extends to all people regardless of (among other aspects)
gender, race, sexual orientation, disability, religion, appearance, veteran status,
gender identity, socioeconomic status, or nationality.

Members of the community will strive to be friendly, patient, and welcoming, especially of
viewpoints and experiences different from our own. We reject harassment and contributions
(in mail, comments, or code) that belittle individuals or groups of people.

We ask all members of the community to be mindful particularly about assumptions of the
gender of users (choice of pronouns in comments and code). We recognize that members
sometimes make mistakes and will, in general, accept sincere regrets for such cases.
Blatant or repeated violations of the code will result in the removal of the
contributor’s participation in the community.

The maintainers of music21 and associated sites will commit themselves to enforcing
this code of conduct. Users who notice violations, including instances of abuse,
harassment, or otherwise unacceptable behavior are requested to contact cuthbert@mit.edu.
Maintainers will respect confidentiality with regard to reports.
